@@ -8,8 +8,8 @@ use URI::QueryParam;
 use Carp;
 use Moo;
 use namespace::clean;
-our $VERSION = "0.04";
-use Data::Dumper;
+our $VERSION = "0.05";
+
 
 $Net::DNS::Lite::CACHE = Cache::LRU->new( size => 512 );
 
@@ -119,11 +119,11 @@ WebService::Bandcamp - A simple and fast interface to the bandcamp.com API
 
 =head1 DESCRIPTION
 
-The module provides a simple interface to the Bandcamp.com API. To use this module, you must first sign up at http://bandcamp.com/developer to receive an API key.
+The module provides a simple interface to the Bandcamp.com API. To use this module, you must first sign up at L<http://bandcamp.com/developer> to receive an API key.
 
 =head1 SEE ALSO
 
-http://bandcamp.com/developer
+L<http://bandcamp.com/developer>
 
 =head1 LICENSE
 
